<?php
/**
 * Plugin Name: ImageAlt AI
 * Plugin URI: https://converswp.com/imagealt-ai
 * Description: Automatically generate SEO-friendly alt text for images using AI
 * Version: 1.0.0
 * Author: ConversWP
 * Author URI: https://converswp.com/
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: imagealt-ai
 * Domain Path: /languages
 * Requires at least: 5.8
 * Requires PHP: 7.4
 */

if (!defined('ABSPATH')) {
    exit;
}

// Plugin constants
define('IMAGEALT_AI_VERSION', '1.0.0');
define('IMAGEALT_AI_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('IMAGEALT_AI_PLUGIN_URL', plugin_dir_url(__FILE__));

// Composer autoloader
require_once IMAGEALT_AI_PLUGIN_DIR . 'vendor/autoload.php';

// Initialize the plugin
\ImageAltAi\Core\Plugin::getInstance();

// Register activation hook to set redirect flag and nonce
register_activation_hook(__FILE__, function() {
    add_option('imagealt_ai_do_activation_redirect', true);
    update_option('imagealt_ai_activation_nonce', wp_create_nonce('imagealt_ai_activation'));
});

// Handle activation redirect with nonce verification
add_action('admin_init', function() {
    if (get_option('imagealt_ai_do_activation_redirect', false)) {
        delete_option('imagealt_ai_do_activation_redirect');
        
        // Verify nonce and check for multi-activation
        $nonce = get_option('imagealt_ai_activation_nonce');
        if (wp_verify_nonce($nonce, 'imagealt_ai_activation') && !isset($_GET['activate-multi'])) {
            delete_option('imagealt_ai_activation_nonce'); // Clean up nonce
            wp_safe_redirect(admin_url('admin.php?page=imagealt-ai'));
            exit;
        }
    }
});