<?php

namespace ImageAltAi\Services;

class OpenAIService implements AiServiceInterface {
    private $api_key;
    
    public function __construct() {
        $this->api_key = get_option('imagealt_ai_openai_api_key');
    }
    
    public function generateImageAlt($image_url, $prompt = '') {

//        $image_url = 'https://www.thrivedesk.com/wp-content/uploads/2023/05/inbox-convo@2x-2048x1145.avif';
//        $image_url = 'https://www.thrivedesk.com/wp-content/uploads/2022/10/multilingual-ui-1.avif';
//        $image_url = 'https://www.thrivedesk.com/wp-content/uploads/2023/01/one-place.png';

        if (empty($this->api_key)) {
            return false;
        }

		// error_log('Generate a concise, descriptive alt text for this image: ' . $image_url . '. Maximum 100 characters. ' . $prompt);

        $response = wp_remote_post('https://api.openai.com/v1/chat/completions', [
            'headers' => [
                'Authorization' => 'Bearer ' . $this->api_key,
                'Content-Type' => 'application/json',
            ],
            'body' => json_encode([
                'model' => 'gpt-4o',
                'messages' => [
                    [
                        'role' => 'user',
                        'content' => [
	                        [
								'type' => 'text',
								'text' => 'Generate a concise, descriptive alt text for this image: ' . $image_url . '. Maximum 100 characters. ' . $prompt,
	                        ],
//	                        ['type' => 'text', 'text' => 'Generate a concise, descriptive alt text for this image and use maximum 100 characters. ' . $prompt],
//	                        ['type' => 'input_image', 'image_data' => base64_encode(file_get_contents($image_url))],
                        ],
//                      'content' => 'Generate a concise, descriptive alt text for this image: ' . $image_url . '. Maximum 100 characters. ' . $prompt,
                    ]
                ],
//                'file' => curl_file_create($image_path), // Include the image file for upload
                'max_tokens' => 200
            ])
        ]);
        
        if (is_wp_error($response)) {
            return false;
        }
        
        $body = json_decode(wp_remote_retrieve_body($response), true);
        $body['prompt'] = 'Generate a concise, descriptive alt text for this image: ' . $image_url . '. Maximum 100 characters. ' . $prompt;

        // log the response
        // error_log(print_r($body, true));
        
        if (empty($body['choices'][0]['message']['content'])) {
            return false;
        }
        
        return trim($body['choices'][0]['message']['content']);
    }
}