<?php

namespace ImageAltAi\Services;

class VisionAiService implements AiServiceInterface {
    private $api_key;
    
    public function __construct() {
        $this->api_key = get_option('imagealt_ai_vision_ai_key');
    }
    
    public function generateImageAlt($image_url) {
        if (empty($this->api_key)) {
            return false;
        }
        
        $response = wp_remote_post('https://vision.googleapis.com/v1/images:annotate', [
            'headers' => [
                'Authorization' => 'Bearer ' . $this->api_key,
                'Content-Type' => 'application/json',
            ],
            'body' => json_encode([
                'requests' => [
                    [
                        'image' => [
                            'source' => [
                                'imageUri' => $image_url
                            ]
                        ],
                        'features' => [
                            [
                                'type' => 'LABEL_DETECTION',
                                'maxResults' => 5
                            ],
                            [
                                'type' => 'IMAGE_PROPERTIES',
                                'maxResults' => 1
                            ]
                        ]
                    ]
                ]
            ])
        ]);
        
        if (is_wp_error($response)) {
            return false;
        }
        
        $body = json_decode(wp_remote_retrieve_body($response), true);
        
        if (empty($body['responses'][0]['labelAnnotations'])) {
            return false;
        }
        
        $labels = array_map(function($label) {
            return $label['description'];
        }, $body['responses'][0]['labelAnnotations']);
        
        return implode(', ', $labels);
    }
}