<?php
if (!defined('ABSPATH')) exit;

// Get stats from the same source as dashboard
$stats = \ImageAltAi\Core\Database::getInstance()->getStats();

// Localize the script with required data
wp_localize_script('imagealt-ai-admin', 'imageAltAi', array(
    'ajaxUrl' => admin_url('admin-ajax.php'),
    'nonce' => wp_create_nonce('imagealt-ai-nonce')
));
?>
<style>
.hidden {
    display: none !important;
}
</style>
<!-- Modal Markup -->
<div id="alt-text-modal" class="modal hidden" style="position: fixed; top: 0; left: 0; width: 100%; height: 100%; display: flex; align-items: center; justify-content: center; z-index: 9999;">
    <div class="modal-overlay" style="position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0, 0, 0, 0.5);"></div>
    <div class="modal-content" style="position: relative; background: white; padding: 20px; border-radius: 8px; width: 90%; max-width: 500px; box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);">
        <div class="modal-header">
            <h2 class="text-xl font-semibold tracking-tight">Alt Text Generation Progress</h2>
            <button id="close-modal-btn" class="close-button button">&times;</button>
        </div>
        <div class="modal-body">
            <div class="progress-overview">
                <p class="text-sm font-medium">Missing Alt Text: <span id="missing-count"><?php echo esc_html($stats['images_without_alt']); ?></span></p>
                <p class="text-sm font-medium">Remaining: <span id="batch-remaining"><?php echo esc_html($stats['images_without_alt']); ?></span></p>

                <div id="batch-table-body"></div>

                <div class="relative w-full h-4 bg-gray-200 rounded">
                    <div id="progress-bar"
                         class="progress-bar absolute top-0 left-0 h-full bg-blue-500 rounded transition-all"
                         style="width: 0%;">
                    </div>
                </div>
                <p id="progress-bar-text" class="mt-2 text-sm text-gray-600 text-center">0% Completed</p>

                <div class="text-center flex justify-center gap-2">
                    <button 
                        id="start-generation-now"
                        class="inline-flex items-center cursor-pointer justify-center whitespace-nowrap rounded-md text-sm font-medium transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50 bg-primary text-primary-foreground shadow hover:bg-primary/90 h-9 px-4 py-2"
                        style="text-decoration: none; background: rgb(79, 70, 229); color: white;"
                        <?php echo $stats['images_without_alt'] === 0 ? 'disabled' : ''; ?>
                    >
                        <?php esc_html_e('Start', 'imagealt-ai'); ?>
                    </button>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
(function($) {
    document.addEventListener('DOMContentLoaded', function() {
        const modal = document.getElementById('alt-text-modal');
        const showModalBtn = document.querySelector('.show-modal');
        const closeModalBtn = document.getElementById('close-modal-btn');
        const startBtn = document.getElementById('start-generation-now');
        const progressBar = document.getElementById('progress-bar');
        const progressText = document.getElementById('progress-bar-text');
        const missingCount = document.getElementById('missing-count');
        const batchRemaining = document.getElementById('batch-remaining');
        
        let isGenerating = false;
        let totalImages = <?php echo esc_js($stats['images_without_alt']); ?>;
        let processedImages = 0;
        let currentPage = 1;
        const perPage = 10;

        function updateStartButtonState() {
            const remainingImages = parseInt(batchRemaining.textContent);
            startBtn.disabled = remainingImages === 0 || isGenerating;
            if (remainingImages === 0) {
                startBtn.textContent = 'No Images to Process';
            } else if (!isGenerating) {
                startBtn.textContent = 'Start';
            }
        }

        function showModal() {
            modal.classList.remove('hidden');
            updateStartButtonState();
        }

        function hideModal() {
            if (!isGenerating) {
                modal.classList.add('hidden');
            }
        }

        function updateProgress() {
            const percentage = Math.round((processedImages / totalImages) * 100);
            progressBar.style.width = percentage + '%';
            progressText.textContent = percentage + '% Completed';
            batchRemaining.textContent = totalImages - processedImages;
        }

        async function updateTotalImageGenerationStats(){
            try {
                    const statsResponse = await $.ajax({
                        url: ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'fetch_images_without_alt',
                            nonce: '<?php echo esc_js(wp_create_nonce("imagealt-ai-nonce")); ?>',
                            page: 1,
                            per_page: 1
                        }
                    });
                    
                    if (statsResponse.success) {
                        missingCount.textContent = statsResponse.data.total_remaining;
                        batchRemaining.textContent = statsResponse.data.total_remaining;
                        
                    }
                } catch (error) {
                    console.error('Error updating stats:', error);
                    window.ImageAltToast.error('Failed to update statistics');
                }
        }

        async function processImagesInBatch(images) {
            for (const image of images) {
                if (!isGenerating) break;
                
                try {
                    // Generate alt text
                    const response = await $.ajax({
                        url: ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'generate_alt_text',
                            nonce: '<?php echo esc_js(wp_create_nonce("imagealt-ai-nonce")); ?>',
                            attachment_id: image.id,
                            auto_save: true
                        }
                    });

                    if (response.success) {
                        processedImages++;
                        updateProgress();
                        window.ImageAltToast.success('Alt text generated and saved successfully');
                    } else {
                        window.ImageAltToast.error('Failed to generate alt text');
                    }
                } catch (error) {
                    console.error('Error generating/saving alt text:', error);
                    window.ImageAltToast.error('Failed to generate or save alt text');
                }
            }
        }

        async function generateAltTextDashboard() {
            if (isGenerating) return;
            
            isGenerating = true;
            startBtn.disabled = true;
            startBtn.textContent = 'Generating...';
            currentPage = 1;
            processedImages = 0;
            window.ImageAltToast.success('Starting alt text generation...');

            try {
                while (isGenerating) {
                    const response = await $.ajax({
                        url: ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'fetch_images_without_alt',
                            nonce: '<?php echo esc_js(wp_create_nonce("imagealt-ai-nonce")); ?>',
                            page: currentPage,
                            per_page: perPage
                        }
                    });
                    
                    if (response.success) {
                        totalImages = response.data.total_remaining;
                        if (response.data.images.length === 0) {
                            window.ImageAltToast.success('All images processed successfully');
                            break;
                        }

                        await processImagesInBatch(response.data.images);
                        currentPage++;
                    } else {
                        window.ImageAltToast.error('Failed to fetch images');
                        break;
                    }
                }
            } catch (error) {
                console.error('Error fetching images:', error);
                window.ImageAltToast.error('Error occurred while processing images');
            } finally {
                isGenerating = false;
                updateStartButtonState();
                updateTotalImageGenerationStats();
            }
        }

        // Event listeners
        showModalBtn.addEventListener('click', showModal);
        closeModalBtn.addEventListener('click', hideModal);
        startBtn.addEventListener('click', generateAltTextDashboard);
    });
})(jQuery);
</script>