<?php
if (!defined('ABSPATH')) exit;

$openai_key = get_option('imagealt_ai_openai_api_key', '');
$vision_key = get_option('imagealt_ai_vision_ai_key', '');
$pre_text = get_option('imagealt_ai_pre_text', '');
$post_text = get_option('imagealt_ai_post_text', '');
$selected_ai = get_option('imagealt_ai_selected_ai', 'openai');
$process_on_upload = get_option('imagealt_ai_process_on_upload', true);
$process_on_view = get_option('imagealt_ai_process_on_view', false);
?>

<!-- Toast Container -->
<div class="toast-container"></div>

<div class="imagealt-ai-action-wrap imagealt-ai-bulk-generator bg-background rounded-lg border border-solid border-[rgb(228,228,231)]  ">
    <div class="imagealt-ai-action-card p-8 ">
        <div class="flex flex-row justify-between">
            <div>
                <h1 class="text-2xl mt-0 mb-0 font-bold tracking-tight"><?php esc_html_e('ImageAlt Generator AI Settings', 'imagealt-ai'); ?></h1>
                <p class="max-w-2xl text-base pb-6 font-light text-gray-500">
                    <?php esc_html_e('Configure the settings for ImageAlt Generator AI. You can select the AI model, set up API keys, and customize the alt text generation process.', 'imagealt-ai'); ?>
                </p>
            </div>

            <div class="plugin-logo">
                <?php
                    printf(
                        '<img src="%s" alt="%s" class="%s" style="%s" loading="lazy">', // phpcs:ignore PluginCheck.CodeAnalysis.ImageFunctions.NonEnqueuedImage
                        esc_url(IMAGEALT_AI_PLUGIN_URL . 'assets/images/logo.png'),
                        esc_attr__('ImageAlt AI Logo', 'imagealt-ai'),
                        esc_attr('w-24 h-auto'),
                        esc_attr('max-width: 150px; height: auto;')
                    );
                ?>
            </div>
        </div>

        <form method="post" action="options.php" class="space-y-4">
            <?php settings_fields('imagealt_ai_settings'); ?>
            
                <div class="rounded-xl border bg-card text-card-foreground shadow p-4">
                    <h2><?php esc_html_e('AI Model Selection', 'imagealt-ai'); ?></h2>
                    <div data-orientation="horizontal" role="none" class="shrink-0 bg-border h-[1px] w-full"></div>

                    <table class="form-table">
                        <tr>
                            <th scope="row"><?php esc_html_e('Select AI Model', 'imagealt-ai'); ?></th>
                            <td>
                                <select name="imagealt_ai_selected_ai" id="imagealt_ai_selected_ai" class="border w-full" style="max-width: 50% !important;">
                                    <option value="openai" <?php selected($selected_ai, 'openai'); ?>>
                                        <?php esc_html_e('OpenAI', 'imagealt-ai'); ?>
                                    </option>
                                    <option value="vision" <?php selected($selected_ai, 'vision'); ?> disabled>
                                        <?php esc_html_e('Google Vision AI', 'imagealt-ai'); ?>
                                    </option>
                                </select>
                            </td>
                        </tr>
                    </table>
                </div>
                
                <div class="rounded-xl border bg-card text-card-foreground shadow p-4">
                    <h2><?php esc_html_e('API Configuration', 'imagealt-ai'); ?></h2>
                    <div data-orientation="horizontal" role="none" class="shrink-0 bg-border h-[1px] w-full"></div>

                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <label for="imagealt_ai_openai_api_key">
                                    <?php esc_html_e('OpenAI API Key', 'imagealt-ai'); ?>
                                </label>
                            </th>
                            <td>
                                <input type="password"
                                    id="imagealt_ai_openai_api_key"
                                    name="imagealt_ai_openai_api_key"
                                    value="<?php echo esc_attr($openai_key); ?>"
                                    class="regular-text w-1/2 border">
                            </td>
                        </tr>
                        
                        <tr>
                            <th scope="row">
                                <label for="imagealt_ai_vision_ai_key">
                                    <?php esc_html_e('Vision AI Key', 'imagealt-ai'); ?>
                                </label>
                            </th>
                            <td>
                                <input type="password"
                                    disabled="disabled"
                                    id="imagealt_ai_vision_ai_key"
                                    name="imagealt_ai_vision_ai_key"
                                    value="<?php echo esc_attr($vision_key); ?>"
                                    class="regular-text w-1/2 border">
                            </td>
                        </tr>
                    </table>
                </div>

                <div class="rounded-xl border bg-card text-card-foreground shadow p-6">
                    <h2><?php esc_html_e('Alt Text Configuration', 'imagealt-ai'); ?></h2>
                    <div data-orientation="horizontal" role="none" class="shrink-0 bg-border h-[1px] w-full"></div>

                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <label for="imagealt_ai_pre_text">
                                    <?php esc_html_e('Pre-text', 'imagealt-ai'); ?>
                                </label>
                            </th>
                            <td style="padding-bottom: 0;">
                                <input type="text"
                                    id="imagealt_ai_pre_text"
                                    name="imagealt_ai_pre_text"
                                    value="<?php echo esc_attr($pre_text); ?>"
                                    class="regular-text w-1/2 border">
                                <p class="description">
                                    <?php esc_html_e('Text to add before the generated alt text', 'imagealt-ai'); ?>
                                </p>
                            </td>
                        </tr>

                        <tr>
                            <th scope="row">
                                <label for="imagealt_ai_post_text">
                                    <?php esc_html_e('Post-text', 'imagealt-ai'); ?>
                                </label>
                            </th>
                            <td style="padding-bottom: 3px;">
                                <input type="text"
                                    id="imagealt_ai_post_text"
                                    name="imagealt_ai_post_text"
                                    value="<?php echo esc_attr($post_text); ?>"
                                    class="regular-text w-1/2 border">
                                <p class="description">
                                    <?php esc_html_e('Text to add after the generated alt text', 'imagealt-ai'); ?>
                                </p>
                            </td>
                        </tr>
                    </table>
                </div>

                <div class="rounded-xl border bg-card text-card-foreground shadow p-4">
                    <h2><?php esc_html_e('Processing Options', 'imagealt-ai'); ?></h2>
                    <div data-orientation="horizontal" role="none" class="shrink-0 bg-border h-[1px] w-full"></div>

                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <?php esc_html_e('Auto Generation', 'imagealt-ai'); ?>
                            </th>
                            <td class="flex flex-col gap-4">
                                <label>
                                    <input type="checkbox"
                                        name="imagealt_ai_process_on_upload"
                                        value="1"
                                        class="regular-text w-1/2"
                                        <?php checked($process_on_upload); ?>>
                                    <?php esc_html_e('Generate alt text when images are uploaded', 'imagealt-ai'); ?>
                                </label>
                                
                                <label>
                                    <input type="checkbox"
                                        name="imagealt_ai_process_on_view"
                                        value="1"
                                        class="regular-text w-1/2"
                                        <?php checked($process_on_view); ?>>
                                    <?php esc_html_e('Generate alt text when posts are viewed', 'imagealt-ai'); ?>
                                </label>
                            </td>
                        </tr>
                    </table>
                </div>
            
                <button type="submit" 
                    class="inline-flex items-center cursor-pointer justify-center whitespace-nowrap rounded-md text-sm font-medium transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50 bg-primary text-primary-foreground shadow hover:bg-primary/90 h-9 px-4 py-2"
                    style="background: rgb(79, 70, 229); color: white;"
                >
                    <?php esc_html_e('Save Changes', 'imagealt-ai'); ?>
                </button>
        </form>
    </div>
</div>

<script>
jQuery(document).ready(function($) {
    // Handle form submission
    $('form').on('submit', function(e) {
        e.preventDefault();

        // submit the form
        $.ajax({
            type: 'POST',
            url: 'options.php',
            data: $(this).serialize(),
            success: function(response) {
                if (window.ImageAltToast) {
                    window.ImageAltToast.success('Settings saved successfully');
                }
            },
            error: function() {
                if (window.ImageAltToast) {
                    window.ImageAltToast.error('Failed to save settings');
                }
            }
        });
    });
});
</script>